Learn R Programming

rosario (version 0.1.1)

temp_overlap: Assemblage-wide temporal niche segregation

Description

Assemblage-wide temporal niche segregation

Usage

temp_overlap(mat, method = c("pianka", "czekanowski"))

Value

The mean temporal overlaping index from a pairwise distance matrix

Arguments

mat

A matrix with species per time columns.

method

A measure of temporal niche overlap between pairs of species

Examples

Run this code
temp_overlap(ex1, method = "pianka")
ex1_rescale <- rescale_matrix(ex1)
temp_overlap(ex1_rescale, method = "czekanowski")

Run the code above in your browser using DataLab