Learn R Programming

rosario (version 0.1.1)

rosario: Generate cyclic and mirrored permutations of a time series

Description

For a numeric vector, creates the set of cyclic shifts and their mirror images (reverse order), preserving shape but changing location along the cycle. The suite of vectors and mirrors represent a complete set of possible distributions.

Usage

rosario(numvec)

Value

A list of numeric vectors with all the permutations in the time series, including the mirror patterns.

Arguments

numvec

Numeric vector representing a single biological identity' distributions across ordered time intervals. Time intervals are assumed to be circular (e.g., hours of the day, months of the year), so the last interval is treated as adjacent to the first. Biological identities can be individuals, populations, species or communities.

See Also

vec_permutation(), rosario_sample()

Examples

Run this code
rosario(c(40, 25, 18, 10, 5, 2))

Run the code above in your browser using DataLab