Learn R Programming

rosario (version 0.1.0)

rosario_sample: ROSARIO randomization of an assemblage matrix

Description

Randomly permutes each row by a uniform cyclic shift of its columns and, with probability 0.5, reverses the order (mirror image). This kind of permutations preserves each biological identity's temporal autocorrelation structure and niche breadth while randomizing location within the cycle.

Usage

rosario_sample(mat)

Value

A numeric matrix of the same dimension as mat, randomized row-wise.

Arguments

mat

Numeric matrix with biological identities in rows and ordered time intervals in columns.

See Also

rosario(), vec_permutation()

Examples

Run this code
rosario_sample(ex1)

Run the code above in your browser using DataLab