powered by
Assemblage-wide temporal niche segregation
temp_overlap(mat, method = c("pianka", "czekanowski"))
The mean temporal overlaping index from a pairwise distance matrix
A matrix with species per time columns.
A measure of temporal niche overlap between pairs of species
temp_overlap(ex1, method = "pianka") ex1_rescale <- rescale_matrix(ex1) temp_overlap(ex1_rescale, method = "czekanowski")
Run the code above in your browser using DataLab