Learn R Programming

rosario (version 0.1.0)

temp_overlap: Mean concurrent temporal niche overlap

Description

Computes the mean of all pairwise overlaps among rows (biological identities) using the chosen index.

Usage

temp_overlap(mat, method = c("pianka", "czekanowski"))

Value

A single numeric value (named by the method) equal to the mean of the lower triangle of the pairwise overlap matrix.

Arguments

mat

Numeric matrix (rows = biological identities, columns = ordered time intervals).

method

Overlap index to use: "pianka" or "czekanowski".

Details

For "czekanowski", rows are automatically rescaled to proportions.

See Also

temp_overlap_matrix(), get_null_model()

Examples

Run this code
temp_overlap(ex1, method = "pianka")
temp_overlap(rescale_matrix(ex1), method = "czekanowski")

Run the code above in your browser using DataLab