powered by
Computes the mean of all pairwise overlaps among rows (biological identities) using the chosen index.
temp_overlap(mat, method = c("pianka", "czekanowski"))
A single numeric value (named by the method) equal to the mean of the lower triangle of the pairwise overlap matrix.
Numeric matrix (rows = biological identities, columns = ordered time intervals).
Overlap index to use: "pianka" or "czekanowski".
"pianka"
"czekanowski"
For "czekanowski", rows are automatically rescaled to proportions.
temp_overlap_matrix(), get_null_model()
temp_overlap_matrix()
get_null_model()
temp_overlap(ex1, method = "pianka") temp_overlap(rescale_matrix(ex1), method = "czekanowski")
Run the code above in your browser using DataLab