powered by
Computes all pairwise overlaps among rows (biological identities) using the chosen index.
temp_overlap_matrix(mat, method = c("pianka", "czekanowski"))
A square symmetric matrix of overlap values with row/colnames copied from mat. The first class of the object is set to the method name.
mat
Numeric matrix (rows = biological identities, columns = ordered time intervals).
Overlap index to use: "pianka" or "czekanowski".
"pianka"
"czekanowski"
For Czekanowski, supply a row-rescaled matrix (see rescale_matrix()) or use temp_overlap(), which handles rescaling.
rescale_matrix()
temp_overlap()
temp_overlap(), rescale_matrix()
temp_overlap_matrix(ex1, method = "pianka") ex1_rescale <- rescale_matrix(ex1) temp_overlap_matrix(ex1_rescale, method = "czekanowski")
Run the code above in your browser using DataLab